# This source code is part of the Biotite package and is distributed
# under the 3-Clause BSD License. Please see 'LICENSE.rst' for further
# information.

"""
This subpackage is used for reading and writing trajectories in the
compressed *Gromacs* XTC format.
"""

__author__ = "Patrick Kunzmann"

from .file import *